Cognitive Load Experiment 2021
=====================================

Thank you for participating in this experiment!  Please try to solve each
problem below to the best of your ability. After you solve each problem please answer
the poll about how much mental effort you used to solve the previous problem.


.. selectquestion:: has22-selq-choice
   :fromid: exp1_pp1a, exp1_q1_write
   :points: 1
   :toggle:

.. selectquestion:: has22-poll-selq-choice
   :fromid: exp1_pp1a_poll, exp1_q1_write_poll
   :points: 1

.. selectquestion:: count-in-range-selq-choice
   :fromid: exp1_q2_write, Count_Target_In_Range_Order
   :points: 1
   :toggle:

.. selectquestion:: count-in-range-poll-selq-choice
   :fromid: exp1_q2_write_poll, Count_Target_In_Range_Order_poll
   :points: 1

.. selectquestion:: diffMaxMin-selq-choice
   :fromid: exp1_pp3, exp1_q3_write
   :points: 1
   :toggle:

.. selectquestion:: diffMaxMin-poll-selq-choice
   :fromid: exp1_pp3_poll, exp1_q3_write_poll
   :points: 1

.. selectquestion:: total-values-selq-choice
   :ab: cogLoadEx1
   :fromid: exp1_q4_total_values, Total_Dict_Values_PP
   :points: 1
   :toggle:

.. selectquestion:: total-values-poll-selq-choice
   :fromid: exp1_q4_total_values_poll, Total_Dict_Values_PP_poll
   :points: 1

.. selectquestion:: get_names-selq-choice
   :fromid: exp1_q5_pp, exp1_q5_write
   :points: 1
   :toggle:

.. selectquestion:: get_names-poll-selq-choice
   :fromid: exp1_q5_pp_poll, exp1_q5_write_poll
   :points: 1
